.. _help:

Help and support
================

If you have any issues with using the repository or have any questions, feel free to reach out!

Contact
-------

- `Email <t.becher@dkfz-heidelberg.de>`_
- `GitHub <https://github.com/tobiasbecher>`_
- `LinkedIn <https://www.linkedin.com/in/tobias-becher-877b93224/>`_
